@@ -27,6 +27,8 @@ READ             = get_event()
 WRITE            = get_event()
 EXPT             = get_event()
 ERROR            = get_event()
+DESTROY          = get_event()
+LOST             = get_event()
 CLOSE            = get_event()
 ACCEPT           = get_event()
 CONNECT          = get_event()
@@ -53,3 +55,5 @@ SSL_CONNECT         = get_event()
 
 
 
+
+
