@@ -1,6 +1,6 @@
-from untwisted.network import xmap, spawn
 from untwisted import iostd
 from untwisted.event import CLOSE, LOAD, DUMPED
+from .iostd import lose
 import os
 
 class DumpStr(iostd.DumpStr):
@@ -8,9 +8,9 @@ class DumpStr(iostd.DumpStr):
         try:
             size = os.write(dev.fd, self.data)  
         except OSError as excpt:
-            self.process_error(dev, excpt.args[0])
+            self.process_error(dev, excpt)
         else:
-            self.data = buffer(self.data, size)
+            self.data = self.data[size:]
 
 class DumpFile(DumpStr, iostd.DumpFile):
     pass
@@ -52,21 +52,20 @@ class Stdout(iostd.Stdout):
         try:
             self.process_data(dev)
         except OSError as excpt:
-            self.process_error(dev, excpt.args[0])
+            self.process_error(dev, excpt)
 
     def process_data(self, dev):
         data = os.read(dev.fd, self.SIZE)
         if not data: 
-            spawn(dev, CLOSE, '') 
+            dev.drive(CLOSE, '') 
         else: 
-            spawn(dev, LOAD, data)
-
-def lose(device):
-    """
-    It is used to close the device and destroy the Device instance.
-    """
-    device.destroy()
-    device.close()
+            dev.drive(LOAD, data)
+
+
+
+
+
+
 
 
 
