@@ -1,8 +1,9 @@
-from socket import socket
-from untwisted.event import READ, WRITE, EXPT, ERROR
-from untwisted.dispatcher import *
+from socket import socket, AF_INET, SOCK_STREAM
+from untwisted.event import READ, WRITE
 from untwisted.core import die
+from untwisted.dispatcher import *
 from untwisted import core
+from untwisted.wrappers import *
 
 class SuperSocket(Dispatcher):
     """
@@ -13,46 +14,30 @@ class SuperSocket(Dispatcher):
         Dispatcher.__init__(self)
         self.fd = fd
         core.gear.register(self)
-
-    def add_map(self, event, handle, *args):
-        Dispatcher.add_map(self, event, handle, *args)
-        core.gear.scale(self)
-
-    def del_map(self, event, handle, *args):
-        Dispatcher.del_map(self, event, handle, *args)
-        core.gear.scale(self)
+        self.dead = False
 
     def destroy(self):
-        self.base.clear()
-        SSL.base.clear()
-        del self.pool[:]
         core.gear.unregister(self)
+        self.dead = True
 
-class SSL(SuperSocket):
-    """
-    Dispatching system for SSL sockets.
-    """
-    def __init__(self, sock):
-        self.sock = sock
-        SuperSocket.__init__(self, sock.fileno())
-
-    def __getattr__(self, name):
-        return getattr(self.sock, name)
-
-class Spin(socket, SuperSocket):
+class Spin(SuperSocket):
     """
     The dispatching system for sockets.
     """
 
     def __init__(self, sock=None):
-        socket.__init__(self, _sock = sock._sock if sock else None)
-        self.setblocking(0) 
-        SuperSocket.__init__(self, self.fileno())
+        self.sock = sock if sock else socket()
+        SuperSocket.__init__(self, self.sock.fileno())
+        self.sock.setblocking(0) 
+
+    def __getattr__(self, name):
+        return getattr(self.sock, name)
 
 class Device(SuperSocket):
     """
     The dispatching system for child processes.
     """
+
     def __init__(self, device):
         from os import O_NONBLOCK
         from fcntl import fcntl, F_GETFL, F_SETFL
@@ -66,6 +51,13 @@ class Device(SuperSocket):
     def __getattr__(self, name):
         return getattr(self.device, name)
 
+class SSL(Spin):
+    """
+    Dispatching system for SSL sockets.
+    """
+
+    pass
+
 
 
 
