@@ -5,7 +5,7 @@ import time
 class CancelCall(Exception):
     pass
 
-class Timer(object):
+class Timer:
     base = []
     def __init__(self, inc, callback, *args, **kwargs):
         self.args         = args
@@ -46,3 +46,4 @@ class Sched(Timer):
 
 
 
+
