@@ -1,9 +1,9 @@
 from socket import socket, AF_INET, SOCK_STREAM
-from untwisted.network import Spin, xmap
+from untwisted.network import Spin
 from untwisted.event import READ
 from threading import Lock
 
-class Waker(object):
+class Waker:
     MAX_SIZE = 6028
     def __init__(self):
         server = socket(AF_INET, SOCK_STREAM)
@@ -16,16 +16,19 @@ class Waker(object):
         def consume(spin):
             spin.recv(self.MAX_SIZE)
 
-        xmap(client, READ, consume)
+        client.add_map(READ, consume)
 
         self.con, addr  = server.accept()
         self.lock       = Lock()
 
     def wake_up(self):
         with self.lock:
-            self.con.send(' ')
+            self.con.send(b' ')
     
 waker = Waker()
 
 
 
+
+
+
